@@ -1,8 +1,6 @@
-import pkg_resources
-
 from pickle_compat.compat import patch, unpatch
 
-__version__ = pkg_resources.get_distribution("pickle-compat").version
+__version__ = "2.1.0"
 
 
 __all__ = [
